/****************************************************************************
** Meta object code from reading C++ file 'mdwslider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kmix-26.08.0/gui/mdwslider.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mdwslider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9MDWSliderE_t {};
} // unnamed namespace

template <> constexpr inline auto MDWSlider::qt_create_metaobjectdata<qt_meta_tag_ZN9MDWSliderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MDWSlider",
        "toggleRecsrc",
        "",
        "toggleMuted",
        "toggleStereoLinked",
        "update",
        "increaseOrDecreaseVolume",
        "arg1",
        "Volume::VolumeTypeFlag",
        "volumeType",
        "addMediaControls",
        "QBoxLayout*",
        "setRecsrc",
        "value",
        "setMuted",
        "volumeChange",
        "increaseVolume",
        "decreaseVolume",
        "mediaPlay",
        "mediaNext",
        "mediaPrev",
        "showMoveMenu",
        "moveStream",
        "checked"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'toggleRecsrc'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleMuted'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleStereoLinked'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'increaseOrDecreaseVolume'
        QtMocHelpers::SlotData<void(bool, Volume::VolumeTypeFlag)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'addMediaControls'
        QtMocHelpers::SlotData<void(QBoxLayout *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 7 },
        }}),
        // Slot 'setRecsrc'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'setMuted'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'volumeChange'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'increaseVolume'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'decreaseVolume'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'mediaPlay'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'mediaNext'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'mediaPrev'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showMoveMenu'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'moveStream'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MDWSlider, qt_meta_tag_ZN9MDWSliderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MDWSlider::staticMetaObject = { {
    QMetaObject::SuperData::link<MixDeviceWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9MDWSliderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9MDWSliderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9MDWSliderE_t>.metaTypes,
    nullptr
} };

void MDWSlider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MDWSlider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toggleRecsrc(); break;
        case 1: _t->toggleMuted(); break;
        case 2: _t->toggleStereoLinked(); break;
        case 3: _t->update(); break;
        case 4: _t->increaseOrDecreaseVolume((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Volume::VolumeTypeFlag>>(_a[2]))); break;
        case 5: _t->addMediaControls((*reinterpret_cast<std::add_pointer_t<QBoxLayout*>>(_a[1]))); break;
        case 6: _t->setRecsrc((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setMuted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->volumeChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->increaseVolume(); break;
        case 10: _t->decreaseVolume(); break;
        case 11: _t->mediaPlay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->mediaNext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->mediaPrev((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->showMoveMenu(); break;
        case 15: _t->moveStream((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *MDWSlider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MDWSlider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9MDWSliderE_t>.strings))
        return static_cast<void*>(this);
    return MixDeviceWidget::qt_metacast(_clname);
}

int MDWSlider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MixDeviceWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
