/****************************************************************************
** Meta object code from reading C++ file 'dbusmixsetwrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kmix-26.08.0/dbus/dbusmixsetwrapper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusmixsetwrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DBusMixSetWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusMixSetWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN17DBusMixSetWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusMixSetWrapper",
        "mixers",
        "",
        "currentMasterMixer",
        "currentMasterControl",
        "preferredMasterMixer",
        "preferredMasterControl",
        "setCurrentMaster",
        "mixer",
        "control",
        "setPreferredMaster",
        "controlsChange",
        "ControlManager::ChangeType",
        "changeType"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'mixers'
        QtMocHelpers::SlotData<QStringList() const>(1, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'currentMasterMixer'
        QtMocHelpers::SlotData<QString() const>(3, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'currentMasterControl'
        QtMocHelpers::SlotData<QString() const>(4, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'preferredMasterMixer'
        QtMocHelpers::SlotData<QString() const>(5, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'preferredMasterControl'
        QtMocHelpers::SlotData<QString() const>(6, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setCurrentMaster'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'setPreferredMaster'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'controlsChange'
        QtMocHelpers::SlotData<void(ControlManager::ChangeType)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mixers'
        QtMocHelpers::PropertyData<QStringList>(1, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'currentMasterMixer'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'currentMasterControl'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'preferredMasterMixer'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'preferredMasterControl'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusMixSetWrapper, qt_meta_tag_ZN17DBusMixSetWrapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusMixSetWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusMixSetWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusMixSetWrapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DBusMixSetWrapperE_t>.metaTypes,
    nullptr
} };

void DBusMixSetWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusMixSetWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QStringList _r = _t->mixers();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->currentMasterMixer();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->currentMasterControl();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->preferredMasterMixer();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->preferredMasterControl();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setCurrentMaster((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->setPreferredMaster((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->controlsChange((*reinterpret_cast<std::add_pointer_t<ControlManager::ChangeType>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->mixers(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentMasterMixer(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->currentMasterControl(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->preferredMasterMixer(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->preferredMasterControl(); break;
        default: break;
        }
    }
}

const QMetaObject *DBusMixSetWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusMixSetWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusMixSetWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusMixSetWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
