/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmix.mixer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MIXERADAPTOR_H
#define MIXERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbus/dbusmixerwrapper.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KMix.Mixer
 */
class MixerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KMix.Mixer")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KMix.Mixer\">\n"
"    <property access=\"read\" type=\"s\" name=\"driverName\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"masterControl\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"opened\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"readableName\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"id\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"udi\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"balance\"/>\n"
"    <property access=\"read\" type=\"as\" name=\"controls\"/>\n"
"    <signal name=\"controlChanged\"/>\n"
"    <signal name=\"changed\"/>\n"
"  </interface>\n"
        "")
public:
    MixerAdaptor(DBusMixerWrapper *parent);
    ~MixerAdaptor() override;

    inline DBusMixerWrapper *parent() const
    { return static_cast<DBusMixerWrapper *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(int balance READ balance WRITE setBalance)
    int balance() const;
    void setBalance(int value);

    Q_PROPERTY(QStringList controls READ controls)
    QStringList controls() const;

    Q_PROPERTY(QString driverName READ driverName)
    QString driverName() const;

    Q_PROPERTY(QString id READ id)
    QString id() const;

    Q_PROPERTY(QString masterControl READ masterControl)
    QString masterControl() const;

    Q_PROPERTY(bool opened READ opened)
    bool opened() const;

    Q_PROPERTY(QString readableName READ readableName)
    QString readableName() const;

    Q_PROPERTY(QString udi READ udi)
    QString udi() const;

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void changed();
    void controlChanged();
};

#endif
