/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmix.control.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CONTROLADAPTOR_H
#define CONTROLADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbus/dbuscontrolwrapper.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KMix.Control
 */
class ControlAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KMix.Control")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KMix.Control\">\n"
"    <property access=\"read\" type=\"s\" name=\"id\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"readableName\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"iconName\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"mute\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"canMute\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"recordSource\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"hasCaptureSwitch\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"volume\"/>\n"
"    <property access=\"readwrite\" type=\"i\" name=\"absoluteVolume\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"absoluteVolumeMin\"/>\n"
"    <property access=\"read\" type=\"i\" name=\"absoluteVolumeMax\"/>\n"
"    <method name=\"increaseVolume\"/>\n"
"    <method name=\"decreaseVolume\"/>\n"
"    <method name=\"toggleMute\"/>\n"
"  </interface>\n"
        "")
public:
    ControlAdaptor(DBusControlWrapper *parent);
    ~ControlAdaptor() override;

    inline DBusControlWrapper *parent() const
    { return static_cast<DBusControlWrapper *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(int absoluteVolume READ absoluteVolume WRITE setAbsoluteVolume)
    int absoluteVolume() const;
    void setAbsoluteVolume(int value);

    Q_PROPERTY(int absoluteVolumeMax READ absoluteVolumeMax)
    int absoluteVolumeMax() const;

    Q_PROPERTY(int absoluteVolumeMin READ absoluteVolumeMin)
    int absoluteVolumeMin() const;

    Q_PROPERTY(bool canMute READ canMute)
    bool canMute() const;

    Q_PROPERTY(bool hasCaptureSwitch READ hasCaptureSwitch)
    bool hasCaptureSwitch() const;

    Q_PROPERTY(QString iconName READ iconName)
    QString iconName() const;

    Q_PROPERTY(QString id READ id)
    QString id() const;

    Q_PROPERTY(bool mute READ mute WRITE setMute)
    bool mute() const;
    void setMute(bool value);

    Q_PROPERTY(QString readableName READ readableName)
    QString readableName() const;

    Q_PROPERTY(bool recordSource READ recordSource WRITE setRecordSource)
    bool recordSource() const;
    void setRecordSource(bool value);

    Q_PROPERTY(int volume READ volume WRITE setVolume)
    int volume() const;
    void setVolume(int value);

public Q_SLOTS: // METHODS
    void decreaseVolume();
    void increaseVolume();
    void toggleMute();
Q_SIGNALS: // SIGNALS
};

#endif
