/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmix.control.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "controladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ControlAdaptor
 */

ControlAdaptor::ControlAdaptor(DBusControlWrapper *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ControlAdaptor::~ControlAdaptor()
{
    // destructor
}

int ControlAdaptor::absoluteVolume() const
{
    // get the value of property absoluteVolume
    return qvariant_cast< int >(parent()->property("absoluteVolume"));
}

void ControlAdaptor::setAbsoluteVolume(int value)
{
    // set the value of property absoluteVolume
    parent()->setProperty("absoluteVolume", QVariant::fromValue(value));
}

int ControlAdaptor::absoluteVolumeMax() const
{
    // get the value of property absoluteVolumeMax
    return qvariant_cast< int >(parent()->property("absoluteVolumeMax"));
}

int ControlAdaptor::absoluteVolumeMin() const
{
    // get the value of property absoluteVolumeMin
    return qvariant_cast< int >(parent()->property("absoluteVolumeMin"));
}

bool ControlAdaptor::canMute() const
{
    // get the value of property canMute
    return qvariant_cast< bool >(parent()->property("canMute"));
}

bool ControlAdaptor::hasCaptureSwitch() const
{
    // get the value of property hasCaptureSwitch
    return qvariant_cast< bool >(parent()->property("hasCaptureSwitch"));
}

QString ControlAdaptor::iconName() const
{
    // get the value of property iconName
    return qvariant_cast< QString >(parent()->property("iconName"));
}

QString ControlAdaptor::id() const
{
    // get the value of property id
    return qvariant_cast< QString >(parent()->property("id"));
}

bool ControlAdaptor::mute() const
{
    // get the value of property mute
    return qvariant_cast< bool >(parent()->property("mute"));
}

void ControlAdaptor::setMute(bool value)
{
    // set the value of property mute
    parent()->setProperty("mute", QVariant::fromValue(value));
}

QString ControlAdaptor::readableName() const
{
    // get the value of property readableName
    return qvariant_cast< QString >(parent()->property("readableName"));
}

bool ControlAdaptor::recordSource() const
{
    // get the value of property recordSource
    return qvariant_cast< bool >(parent()->property("recordSource"));
}

void ControlAdaptor::setRecordSource(bool value)
{
    // set the value of property recordSource
    parent()->setProperty("recordSource", QVariant::fromValue(value));
}

int ControlAdaptor::volume() const
{
    // get the value of property volume
    return qvariant_cast< int >(parent()->property("volume"));
}

void ControlAdaptor::setVolume(int value)
{
    // set the value of property volume
    parent()->setProperty("volume", QVariant::fromValue(value));
}

void ControlAdaptor::decreaseVolume()
{
    // handle method call org.kde.KMix.Control.decreaseVolume
    parent()->decreaseVolume();
}

void ControlAdaptor::increaseVolume()
{
    // handle method call org.kde.KMix.Control.increaseVolume
    parent()->increaseVolume();
}

void ControlAdaptor::toggleMute()
{
    // handle method call org.kde.KMix.Control.toggleMute
    parent()->toggleMute();
}


#include "moc_controladaptor.cpp"
