/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmix.mixer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "mixeradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class MixerAdaptor
 */

MixerAdaptor::MixerAdaptor(DBusMixerWrapper *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

MixerAdaptor::~MixerAdaptor()
{
    // destructor
}

int MixerAdaptor::balance() const
{
    // get the value of property balance
    return qvariant_cast< int >(parent()->property("balance"));
}

void MixerAdaptor::setBalance(int value)
{
    // set the value of property balance
    parent()->setProperty("balance", QVariant::fromValue(value));
}

QStringList MixerAdaptor::controls() const
{
    // get the value of property controls
    return qvariant_cast< QStringList >(parent()->property("controls"));
}

QString MixerAdaptor::driverName() const
{
    // get the value of property driverName
    return qvariant_cast< QString >(parent()->property("driverName"));
}

QString MixerAdaptor::id() const
{
    // get the value of property id
    return qvariant_cast< QString >(parent()->property("id"));
}

QString MixerAdaptor::masterControl() const
{
    // get the value of property masterControl
    return qvariant_cast< QString >(parent()->property("masterControl"));
}

bool MixerAdaptor::opened() const
{
    // get the value of property opened
    return qvariant_cast< bool >(parent()->property("opened"));
}

QString MixerAdaptor::readableName() const
{
    // get the value of property readableName
    return qvariant_cast< QString >(parent()->property("readableName"));
}

QString MixerAdaptor::udi() const
{
    // get the value of property udi
    return qvariant_cast< QString >(parent()->property("udi"));
}


#include "moc_mixeradaptor.cpp"
