/****************************************************************************
** Meta object code from reading C++ file 'mixsetadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mixsetadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mixsetadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MixSetAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MixSetAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13MixSetAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MixSetAdaptor",
        "D-Bus Interface",
        "org.kde.KMix.MixSet",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.KMix.MixSet\">\n    <property access=\""
        "read\" type=\"as\" name=\"mixers\"/>\n    <property access=\"read\""
        " type=\"s\" name=\"currentMasterMixer\"/>\n    <property access=\""
        "read\" type=\"s\" name=\"currentMasterControl\"/>\n    <property a"
        "ccess=\"read\" type=\"s\" name=\"preferredMasterMixer\"/>\n    <pr"
        "operty access=\"read\" type=\"s\" name=\"preferredMasterControl\"/"
        ">\n    <method name=\"setCurrentMaster\">\n      <arg direction=\""
        "in\" type=\"s\" name=\"mixer\"/>\n      <arg direction=\"in\" type"
        "=\"s\" name=\"control\"/>\n    </method>\n    <method name=\"setPr"
        "eferredMaster\">\n      <arg direction=\"in\" type=\"s\" name=\"mi"
        "xer\"/>\n      <arg direction=\"in\" type=\"s\" name=\"control\"/>"
        "\n    </method>\n    <signal name=\"mixersChanged\"/>\n    <signal"
        " name=\"masterChanged\"/>\n  </interface>\n",
        "masterChanged",
        "",
        "mixersChanged",
        "setCurrentMaster",
        "mixer",
        "control",
        "setPreferredMaster",
        "currentMasterControl",
        "currentMasterMixer",
        "mixers",
        "preferredMasterControl",
        "preferredMasterMixer"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'masterChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mixersChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentMaster'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'setPreferredMaster'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentMasterControl'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'currentMasterMixer'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'mixers'
        QtMocHelpers::PropertyData<QStringList>(14, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'preferredMasterControl'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'preferredMasterMixer'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MixSetAdaptor, qt_meta_tag_ZN13MixSetAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MixSetAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MixSetAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MixSetAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MixSetAdaptorE_t>.metaTypes,
    nullptr
} };

void MixSetAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MixSetAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->masterChanged(); break;
        case 1: _t->mixersChanged(); break;
        case 2: _t->setCurrentMaster((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->setPreferredMaster((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MixSetAdaptor::*)()>(_a, &MixSetAdaptor::masterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MixSetAdaptor::*)()>(_a, &MixSetAdaptor::mixersChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->currentMasterControl(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->currentMasterMixer(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->mixers(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->preferredMasterControl(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->preferredMasterMixer(); break;
        default: break;
        }
    }
}

const QMetaObject *MixSetAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MixSetAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MixSetAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MixSetAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void MixSetAdaptor::masterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MixSetAdaptor::mixersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
