/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmix.mixset.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MIXSETADAPTOR_H
#define MIXSETADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbus/dbusmixsetwrapper.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KMix.MixSet
 */
class MixSetAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KMix.MixSet")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KMix.MixSet\">\n"
"    <property access=\"read\" type=\"as\" name=\"mixers\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"currentMasterMixer\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"currentMasterControl\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"preferredMasterMixer\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"preferredMasterControl\"/>\n"
"    <method name=\"setCurrentMaster\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"mixer\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"control\"/>\n"
"    </method>\n"
"    <method name=\"setPreferredMaster\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"mixer\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"control\"/>\n"
"    </method>\n"
"    <signal name=\"mixersChanged\"/>\n"
"    <signal name=\"masterChanged\"/>\n"
"  </interface>\n"
        "")
public:
    MixSetAdaptor(DBusMixSetWrapper *parent);
    ~MixSetAdaptor() override;

    inline DBusMixSetWrapper *parent() const
    { return static_cast<DBusMixSetWrapper *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString currentMasterControl READ currentMasterControl)
    QString currentMasterControl() const;

    Q_PROPERTY(QString currentMasterMixer READ currentMasterMixer)
    QString currentMasterMixer() const;

    Q_PROPERTY(QStringList mixers READ mixers)
    QStringList mixers() const;

    Q_PROPERTY(QString preferredMasterControl READ preferredMasterControl)
    QString preferredMasterControl() const;

    Q_PROPERTY(QString preferredMasterMixer READ preferredMasterMixer)
    QString preferredMasterMixer() const;

public Q_SLOTS: // METHODS
    void setCurrentMaster(const QString &mixer, const QString &control);
    void setPreferredMaster(const QString &mixer, const QString &control);
Q_SIGNALS: // SIGNALS
    void masterChanged();
    void mixersChanged();
};

#endif
