/****************************************************************************
** Meta object code from reading C++ file 'kmixwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kmix-26.08.0/apps/kmixwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmixwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KMixWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KMixWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10KMixWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMixWindow",
        "controlsChange",
        "",
        "ControlManager::ChangeType",
        "changeType",
        "showSettings",
        "showHelp",
        "showAbout",
        "toggleMenuBar",
        "loadVolumes",
        "postfix",
        "saveVolumes",
        "saveConfig",
        "recreateGUI",
        "saveView",
        "reset",
        "mixerId",
        "forceNewTab",
        "recreateGUIwithSavingView",
        "newMixerShown",
        "tabIndex",
        "slotSelectMaster",
        "applyPrefs",
        "KMixPrefDlg::PrefChanges",
        "changed",
        "slotKdeAudioSetupExec",
        "slotConfigureCurrentView",
        "plugged",
        "const char*",
        "driverName",
        "udi",
        "dev",
        "unplugged",
        "slotIncreaseVolume",
        "slotDecreaseVolume",
        "slotMute",
        "newView",
        "saveAndCloseView",
        "loadVolumes1",
        "loadVolumes2",
        "loadVolumes3",
        "loadVolumes4",
        "saveVolumes1",
        "saveVolumes2",
        "saveVolumes3",
        "saveVolumes4"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'controlsChange'
        QtMocHelpers::SlotData<void(ControlManager::ChangeType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'showSettings'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showHelp'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showAbout'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleMenuBar'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadVolumes'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'loadVolumes'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'saveVolumes'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'saveVolumes'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'saveConfig'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'recreateGUI'
        QtMocHelpers::SlotData<void(bool, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'recreateGUI'
        QtMocHelpers::SlotData<void(bool, const QString &, bool, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 }, { QMetaType::QString, 16 }, { QMetaType::Bool, 17 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'recreateGUIwithSavingView'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newMixerShown'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'slotSelectMaster'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applyPrefs'
        QtMocHelpers::SlotData<void(KMixPrefDlg::PrefChanges)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'slotKdeAudioSetupExec'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConfigureCurrentView'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'plugged'
        QtMocHelpers::SlotData<void(const char *, const QString &, int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 }, { QMetaType::QString, 30 }, { QMetaType::Int, 31 },
        }}),
        // Slot 'unplugged'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'slotIncreaseVolume'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDecreaseVolume'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMute'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newView'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveAndCloseView'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'loadVolumes1'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadVolumes2'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadVolumes3'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadVolumes4'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveVolumes1'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveVolumes2'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveVolumes3'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveVolumes4'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMixWindow, qt_meta_tag_ZN10KMixWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMixWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KMixWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KMixWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KMixWindowE_t>.metaTypes,
    nullptr
} };

void KMixWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMixWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->controlsChange((*reinterpret_cast<std::add_pointer_t<ControlManager::ChangeType>>(_a[1]))); break;
        case 1: _t->showSettings(); break;
        case 2: _t->showHelp(); break;
        case 3: _t->showAbout(); break;
        case 4: _t->toggleMenuBar(); break;
        case 5: _t->loadVolumes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->loadVolumes(); break;
        case 7: _t->saveVolumes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->saveVolumes(); break;
        case 9: _t->saveConfig(); break;
        case 10: _t->recreateGUI((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->recreateGUI((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 12: _t->recreateGUIwithSavingView(); break;
        case 13: _t->newMixerShown((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->slotSelectMaster(); break;
        case 15: _t->applyPrefs((*reinterpret_cast<std::add_pointer_t<KMixPrefDlg::PrefChanges>>(_a[1]))); break;
        case 16: _t->slotKdeAudioSetupExec(); break;
        case 17: _t->slotConfigureCurrentView(); break;
        case 18: _t->plugged((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 19: _t->unplugged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->slotIncreaseVolume(); break;
        case 21: _t->slotDecreaseVolume(); break;
        case 22: _t->slotMute(); break;
        case 23: _t->newView(); break;
        case 24: _t->saveAndCloseView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->loadVolumes1(); break;
        case 26: _t->loadVolumes2(); break;
        case 27: _t->loadVolumes3(); break;
        case 28: _t->loadVolumes4(); break;
        case 29: _t->saveVolumes1(); break;
        case 30: _t->saveVolumes2(); break;
        case 31: _t->saveVolumes3(); break;
        case 32: _t->saveVolumes4(); break;
        default: ;
        }
    }
}

const QMetaObject *KMixWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMixWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KMixWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KMixWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 33;
    }
    return _id;
}
QT_WARNING_POP
