/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmix.mixset.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "mixsetadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class MixSetAdaptor
 */

MixSetAdaptor::MixSetAdaptor(DBusMixSetWrapper *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

MixSetAdaptor::~MixSetAdaptor()
{
    // destructor
}

QString MixSetAdaptor::currentMasterControl() const
{
    // get the value of property currentMasterControl
    return qvariant_cast< QString >(parent()->property("currentMasterControl"));
}

QString MixSetAdaptor::currentMasterMixer() const
{
    // get the value of property currentMasterMixer
    return qvariant_cast< QString >(parent()->property("currentMasterMixer"));
}

QStringList MixSetAdaptor::mixers() const
{
    // get the value of property mixers
    return qvariant_cast< QStringList >(parent()->property("mixers"));
}

QString MixSetAdaptor::preferredMasterControl() const
{
    // get the value of property preferredMasterControl
    return qvariant_cast< QString >(parent()->property("preferredMasterControl"));
}

QString MixSetAdaptor::preferredMasterMixer() const
{
    // get the value of property preferredMasterMixer
    return qvariant_cast< QString >(parent()->property("preferredMasterMixer"));
}

void MixSetAdaptor::setCurrentMaster(const QString &mixer, const QString &control)
{
    // handle method call org.kde.KMix.MixSet.setCurrentMaster
    parent()->setCurrentMaster(mixer, control);
}

void MixSetAdaptor::setPreferredMaster(const QString &mixer, const QString &control)
{
    // handle method call org.kde.KMix.MixSet.setPreferredMaster
    parent()->setPreferredMaster(mixer, control);
}


#include "moc_mixsetadaptor.cpp"
